@@ -2,11 +2,21 @@ from contextlib import contextmanager
 from time import sleep
 from bisect import bisect_left
 from itertools import combinations_with_replacement
+from typing import Collection
 from .Operators import prod
 
-def lcm(numbers):
+def lcm(numbers: Collection = None, *args: int) -> int:
+    """Returns lowest common multiplier of EITHER:
+    numbers (any collection-like object which can be converted into a list) given as a single argument OR
+    a series of numbers given as multiple arguments
+    """
     prime = PrimeNumbers()
-    numbers = list(numbers) #otherwise first test numbers != old_numbers always returns true
+    try:
+        numbers = list(numbers)
+    except TypeError:
+        numbers = [numbers]
+    if args:
+        numbers += [arg for arg in args] #otherwise first test numbers != old_numbers always returns true
     old_numbers=[]
     lcm = 1
     for p in prime:
@@ -19,7 +29,7 @@ def lcm(numbers):
                 break
         if sum(numbers) == len(numbers):
             break
-    return lcm
+    return int(lcm)
 
 class PrimeNumbers(object):
     """Iterable object which yields prime numbers
